@@ -93,7 +93,7 @@ int gen_anon_server_kx( GNUTLS_STATE state, opaque** data) {
 		state->gnutls_key->auth_info_type = GNUTLS_ANON;
 		state->gnutls_key->auth_info_size = sizeof(ANON_SERVER_AUTH_INFO_INT);
 	} else 
-		if (gnutls_get_auth_type( state) != state->gnutls_key->auth_info_type) {
+		if (gnutls_auth_get_type( state) != state->gnutls_key->auth_info_type) {
 	        	gnutls_assert();
 	                return GNUTLS_E_INVALID_REQUEST;
 		}	                         	 			 			
@@ -194,34 +194,33 @@ int proc_anon_server_kx( GNUTLS_STATE state, opaque* data, int data_size) {
 
 
 	i = 0;
+	DECR_LEN( data_size, 2);
 	n_p = READuint16( &data[i]);
 	i += 2;
 
+	DECR_LEN( data_size, n_p);
 	data_p = &data[i];
 	i += n_p;
 	if (i > data_size) {
 		gnutls_assert();
 		return GNUTLS_E_UNEXPECTED_PACKET_LENGTH;
 	}
+	DECR_LEN( data_size, 2);
 	n_g = READuint16( &data[i]);
 	i += 2;
 
+	DECR_LEN( data_size, n_g);
 	data_g = &data[i];
 	i += n_g;
-	if (i > data_size) {
-		gnutls_assert();
-		return GNUTLS_E_UNEXPECTED_PACKET_LENGTH;
-	}
 	
+	DECR_LEN( data_size, 2);
 	n_Y = READuint16( &data[i]);
 	i += 2;
 
+	DECR_LEN( data_size, n_Y);
 	data_Y = &data[i];
 	i += n_Y;
-	if (i > data_size) {
-		gnutls_assert();
-		return GNUTLS_E_UNEXPECTED_PACKET_LENGTH;
-	}
+
 	_n_Y = n_Y;
 	_n_g = n_g;
 	_n_p = n_p;
@@ -241,10 +240,18 @@ int proc_anon_server_kx( GNUTLS_STATE state, opaque* data, int data_size) {
 	}
 
 	/* set auth_info */
-	state->gnutls_key->auth_info = gnutls_malloc(sizeof(ANON_CLIENT_AUTH_INFO));
+	if (state->gnutls_key->auth_info==NULL)
+		state->gnutls_key->auth_info = gnutls_malloc(sizeof(ANON_CLIENT_AUTH_INFO));
+	else
+		if (gnutls_auth_get_type( state) != state->gnutls_key->auth_info_type) {
+	        	gnutls_assert();
+	                return GNUTLS_E_INVALID_REQUEST;
+		}	                         	 			 			
+
 	if (state->gnutls_key->auth_info==NULL) return GNUTLS_E_MEMORY_ERROR;
 	((ANON_CLIENT_AUTH_INFO)state->gnutls_key->auth_info)->dh_bits = gcry_mpi_get_nbits(state->gnutls_key->client_p);
 	state->gnutls_key->auth_info_size = sizeof(ANON_CLIENT_AUTH_INFO_INT);
+	state->gnutls_key->auth_info_type = GNUTLS_ANON;
 
 	/* We should check signature in non-anonymous KX 
 	 * this is anonymous however
@@ -267,9 +274,11 @@ int proc_anon_client_kx( GNUTLS_STATE state, opaque* data, int data_size) {
 		bits = cred->dh_bits;
 	}
 
+	DECR_LEN( data_size, 2);
 	n_Y = READuint16( &data[0]);
 
 	_n_Y = n_Y;
+	DECR_LEN( data_size, n_Y);
 	if (_gnutls_mpi_scan(&state->gnutls_key->client_Y, &data[2], &_n_Y) !=0 || state->gnutls_key->client_Y==NULL) {
 		gnutls_assert();
 		return GNUTLS_E_MPI_SCAN_FAILED;
