@@ -498,7 +498,7 @@ int _gnutls_proc_x509_server_certificate(GNUTLS_STATE state, opaque * data,
 
 		state->gnutls_key->auth_info_type = GNUTLS_X509PKI;
 	} else
-	    if (gnutls_get_auth_type(state) !=
+	    if (gnutls_auth_get_type(state) !=
 		state->gnutls_key->auth_info_type) {
 		gnutls_assert();
 		return GNUTLS_E_INVALID_REQUEST;
@@ -518,20 +518,27 @@ int _gnutls_proc_x509_server_certificate(GNUTLS_STATE state, opaque * data,
 	}
 	i = dsize;
 
+	DECR_LEN(dsize, 3);
 	len = READuint24(p);
 	p += 3;
 
 	for (; i > 0; len = READuint24(p), p += 3) {
-		DECR_LEN(dsize, (len + 3));
+		DECR_LEN(dsize, len);
 		peer_certificate_list_size++;
 		p += len;
 		i -= len + 3;
+		if (i>0) DECR_LEN(dsize, 3);
 	}
 
 	if (peer_certificate_list_size == 0) {
 		gnutls_assert();
 		return GNUTLS_E_UNEXPECTED_PACKET_LENGTH;
 	}
+
+	/* Now we start parsing the list (again).
+	 * We don't use DECR_LEN since the list has
+	 * been parsed before.
+	 */
 	dsize = data_size;
 	i = dsize;
 	peer_certificate_list =
@@ -690,6 +697,7 @@ int _gnutls_proc_x509_cert_req(GNUTLS_STATE state, opaque * data,
 		return 0;
 	}
 
+	DECR_LEN(dsize, size);
 	if ((ret =
 	     _gnutls_find_acceptable_client_cert(state, p, size,
 						 &ind)) < 0) {
@@ -772,10 +780,7 @@ int _gnutls_proc_x509_client_cert_vrfy(GNUTLS_STATE state, opaque * data,
 	size = READuint16(pdata);
 	pdata += 2;
 
-	if (size < data_size - 2) {
-		gnutls_assert();
-		return GNUTLS_E_UNEXPECTED_PACKET_LENGTH;
-	}
+	DECR_LEN(dsize, size);
 
 	sig.data = pdata;
 	sig.size = size;
@@ -921,7 +926,7 @@ int _gnutls_find_apr_cert(GNUTLS_STATE state, gnutls_cert ** apr_cert_list,
 	return 0;
 }
 
-#define CHECK_AUTH(auth, ret) if (gnutls_get_auth_type(state) != auth) { \
+#define CHECK_AUTH(auth, ret) if (gnutls_auth_get_type(state) != auth) { \
 	gnutls_assert(); \
 	return ret; \
 	}
@@ -1205,7 +1210,7 @@ int gnutls_x509pki_extract_certificate_version(const gnutls_datum * cert)
   * @state: is a gnutls state
   *
   * This function will try to verify the peer's certificate and return it's status (TRUSTED, EXPIRED etc.). 
-  * Status should be one of the CertificateStatus enumerated elements.
+  * The return value (status) should be one of the CertificateStatus enumerated elements.
   * However you must also check the peer's name in order to check if the verified certificate belongs to the 
   * actual peer. Returns a negative error code in case of an error, or GNUTLS_CERT_NONE if no certificate was sent.
   *
