@@ -25,7 +25,7 @@
 extern "C" {
 #endif
 
-#define LIBGNUTLS_VERSION "0.2.91"
+#define LIBGNUTLS_VERSION "0.3.0"
 
 #include <sys/types.h>
 #include <time.h>
@@ -52,7 +52,7 @@ typedef enum AlertDescription { GNUTLS_A_CLOSE_NOTIFY, GNUTLS_A_UNEXPECTED_MESSA
 
 typedef enum GNUTLS_NAME_IND { GNUTLS_DNSNAME=1 } GNUTLS_NAME_IND; 
 typedef enum CertificateStatus { GNUTLS_CERT_TRUSTED=1, GNUTLS_CERT_NOT_TRUSTED, GNUTLS_CERT_EXPIRED, GNUTLS_CERT_INVALID, GNUTLS_CERT_NONE } CertificateStatus;
-typedef enum CertificateRequest { GNUTLS_CERT_REQUEST=1, GNUTLS_CERT_REQUIRE } CertificateRequest;
+typedef enum CertificateRequest { GNUTLS_CERT_IGNORE, GNUTLS_CERT_REQUEST=1, GNUTLS_CERT_REQUIRE } CertificateRequest;
 typedef enum CloseRequest { GNUTLS_SHUT_RDWR=0, GNUTLS_SHUT_WR=1 } CloseRequest;
 
 typedef enum GNUTLS_Version { GNUTLS_SSL3=1, GNUTLS_TLS1 } GNUTLS_Version;
@@ -93,9 +93,9 @@ int gnutls_check_pending(GNUTLS_STATE state);
 int gnutls_rehandshake( GNUTLS_STATE state);
 
 
-AlertDescription gnutls_get_last_alert( GNUTLS_STATE state);
-int 		 gnutls_send_alert(GNUTLS_SOCKET_PTR, GNUTLS_STATE, AlertLevel, AlertDescription);
-int 		 gnutls_send_appropriate_alert(  GNUTLS_STATE state, int err);
+AlertDescription gnutls_alert_get_last( GNUTLS_STATE state);
+int 		 gnutls_alert_send(GNUTLS_SOCKET_PTR, GNUTLS_STATE, AlertLevel, AlertDescription);
+int 		 gnutls_alert_send_appropriate(  GNUTLS_STATE state, int err);
 
 /* get information on the current state */
 BulkCipherAlgorithm gnutls_cipher_get_algo( GNUTLS_STATE state);
@@ -141,8 +141,7 @@ typedef int (*DB_STORE_FUNC)(void*, gnutls_datum key, gnutls_datum data);
 typedef int (*DB_REMOVE_FUNC)(void*, gnutls_datum key);
 typedef gnutls_datum (*DB_RETR_FUNC)(void*, gnutls_datum key);
 
-void gnutls_set_lowat( GNUTLS_STATE state, int num);
-void gnutls_set_cache_expiration( GNUTLS_STATE state, int seconds);
+void gnutls_db_set_cache_expiration( GNUTLS_STATE state, int seconds);
 
 int  gnutls_db_set_name( GNUTLS_STATE state, char* filename);	
 int  gnutls_db_clean( GNUTLS_STATE state);
@@ -153,7 +152,7 @@ void gnutls_db_set_ptr( GNUTLS_STATE, void* db_ptr);
 void* gnutls_db_get_ptr( GNUTLS_STATE);
 int  gnutls_db_check_entry( GNUTLS_STATE state, gnutls_datum session_entry);
 
-void gnutls_set_max_handshake_data_buffer_size( GNUTLS_STATE state, int max);
+void gnutls_handshake_set_max_data_buffer_size( GNUTLS_STATE state, int max);
 
 /* returns libgnutls version */
 const char* gnutls_check_version();
@@ -161,7 +160,7 @@ const char* gnutls_check_version();
 /* Functions for setting/clearing credentials */
 int gnutls_clear_creds( GNUTLS_STATE state);
 /* cred is a structure defined by the kx algorithm */
-int gnutls_set_cred( GNUTLS_STATE, CredType type, void* cred);
+int gnutls_cred_set( GNUTLS_STATE, CredType type, void* cred);
 
 /* This will set the Common Name field in case of X509PKI
  * authentication. This will be used while verifying the
@@ -187,7 +186,7 @@ int gnutls_srp_set_client_cred( SRP_CLIENT_CREDENTIALS res, char *username, char
 
 void gnutls_srp_free_server_sc( SRP_SERVER_CREDENTIALS sc);
 int gnutls_srp_allocate_server_sc( SRP_SERVER_CREDENTIALS *sc);
-int gnutls_srp_set_server_cred( SRP_SERVER_CREDENTIALS res, char *password_file, char* password_conf_file);
+int gnutls_srp_set_server_cred_file( SRP_SERVER_CREDENTIALS res, char *password_file, char* password_conf_file);
 
 void gnutls_anon_free_server_sc( ANON_SERVER_CREDENTIALS sc);
 int gnutls_anon_allocate_server_sc( ANON_SERVER_CREDENTIALS *sc);
@@ -203,18 +202,18 @@ int gnutls_anon_set_client_cred( ANON_SERVER_CREDENTIALS res, int dh_bits);
  */
 void gnutls_x509pki_free_sc( X509PKI_CREDENTIALS sc);
 int gnutls_x509pki_allocate_sc( X509PKI_CREDENTIALS *sc, int ncerts);
-int gnutls_x509pki_set_key( X509PKI_CREDENTIALS res, char *CERTFILE, char* KEYFILE);
-int gnutls_x509pki_set_trust( X509PKI_CREDENTIALS res, char* CAFILE, char* CRLFILE);
+int gnutls_x509pki_set_key_file( X509PKI_CREDENTIALS res, char *CERTFILE, char* KEYFILE);
+int gnutls_x509pki_set_trust_file( X509PKI_CREDENTIALS res, char* CAFILE, char* CRLFILE);
 
 #define gnutls_x509pki_free_server_sc gnutls_x509pki_free_sc
 #define gnutls_x509pki_allocate_server_sc gnutls_x509pki_allocate_sc
-#define gnutls_x509pki_set_server_key gnutls_x509pki_set_key
-#define gnutls_x509pki_set_server_trust gnutls_x509pki_set_trust
+#define gnutls_x509pki_set_server_key_file gnutls_x509pki_set_key_file
+#define gnutls_x509pki_set_server_trust_file gnutls_x509pki_set_trust_file
 
 #define gnutls_x509pki_free_client_sc gnutls_x509pki_free_sc
 #define gnutls_x509pki_allocate_client_sc gnutls_x509pki_allocate_sc
-#define gnutls_x509pki_set_client_key gnutls_x509pki_set_key
-#define gnutls_x509pki_set_client_trust gnutls_x509pki_set_trust
+#define gnutls_x509pki_set_client_key_file gnutls_x509pki_set_key_file
+#define gnutls_x509pki_set_client_trust_file gnutls_x509pki_set_trust_file
 
 
 /* global state functions 
@@ -234,13 +233,15 @@ typedef ssize_t (*GNUTLS_PUSH_FUNC)(GNUTLS_SOCKET_PTR, const void*, size_t);
 void gnutls_transport_set_ptr(GNUTLS_STATE state, GNUTLS_SOCKET_PTR ptr);
 GNUTLS_SOCKET_PTR gnutls_transport_get_ptr(GNUTLS_STATE state);
 
+void gnutls_transport_set_lowat( GNUTLS_STATE state, int num);
+
 typedef void (*LOG_FUNC)( const char*);
 
 void gnutls_transport_set_push_function( GNUTLS_STATE, GNUTLS_PUSH_FUNC push_func);
 void gnutls_transport_set_pull_function( GNUTLS_STATE, GNUTLS_PULL_FUNC pull_func);
 
-size_t gnutls_get_max_record_size( GNUTLS_STATE state);
-size_t gnutls_set_max_record_size( GNUTLS_STATE state, size_t size);
+size_t gnutls_record_get_max_size( GNUTLS_STATE state);
+size_t gnutls_record_set_max_size( GNUTLS_STATE state, size_t size);
 
 #ifndef GNUTLS_UI_H
 # define GNUTLS_UI_H
@@ -288,7 +289,7 @@ typedef int x509pki_server_cert_callback_func(GNUTLS_STATE, const gnutls_datum *
 /* Functions that allow AUTH_INFO structures handling
  */
 
-CredType gnutls_get_auth_type( GNUTLS_STATE state);
+CredType gnutls_auth_get_type( GNUTLS_STATE state);
 
 /* SRP */
 
