@@ -38,12 +38,10 @@ typedef struct {
 } gnutls_cred_map;
 
 static const gnutls_cred_map cred_mappings[] = {
-	{ GNUTLS_KX_DH_ANON, GNUTLS_ANON    },
-	{ GNUTLS_KX_RSA,     GNUTLS_X509PKI },
-	{ GNUTLS_KX_DHE_DSS, GNUTLS_X509PKI },
-	{ GNUTLS_KX_DHE_RSA, GNUTLS_X509PKI },
-	{ GNUTLS_KX_DH_DSS,  GNUTLS_X509PKI },
-	{ GNUTLS_KX_DH_RSA,  GNUTLS_X509PKI },
+	{ GNUTLS_KX_ANON_DH, GNUTLS_ANON    },
+	{ GNUTLS_KX_X509PKI_RSA,     GNUTLS_X509PKI },
+	{ GNUTLS_KX_X509PKI_DHE_DSS, GNUTLS_X509PKI },
+	{ GNUTLS_KX_X509PKI_DHE_RSA, GNUTLS_X509PKI },
 	{ GNUTLS_KX_SRP,     GNUTLS_SRP     },
 	{ 0 }
 };
@@ -100,12 +98,12 @@ typedef struct gnutls_cipher_entry gnutls_cipher_entry;
  * protecting communications" by Hugo Krawczyk - CRYPTO 2001
  */
 static const gnutls_cipher_entry algorithms[] = {
-	GNUTLS_CIPHER_ENTRY(GNUTLS_3DES_CBC, 8, 24, CIPHER_BLOCK, 8),
-	GNUTLS_CIPHER_ENTRY(GNUTLS_RIJNDAEL_CBC, 16, 16, CIPHER_BLOCK, 16),
-	GNUTLS_CIPHER_ENTRY(GNUTLS_RIJNDAEL256_CBC, 16, 32, CIPHER_BLOCK, 16),
-	GNUTLS_CIPHER_ENTRY(GNUTLS_TWOFISH_CBC, 16, 16, CIPHER_BLOCK, 16),
-	GNUTLS_CIPHER_ENTRY(GNUTLS_ARCFOUR, 1, 16, CIPHER_STREAM, 0),
-	GNUTLS_CIPHER_ENTRY(GNUTLS_NULL_CIPHER, 1, 0, CIPHER_STREAM, 0),
+	GNUTLS_CIPHER_ENTRY(GNUTLS_CIPHER_3DES_CBC, 8, 24, CIPHER_BLOCK, 8),
+	GNUTLS_CIPHER_ENTRY(GNUTLS_CIPHER_RIJNDAEL_CBC, 16, 16, CIPHER_BLOCK, 16),
+	GNUTLS_CIPHER_ENTRY(GNUTLS_CIPHER_RIJNDAEL256_CBC, 16, 32, CIPHER_BLOCK, 16),
+	GNUTLS_CIPHER_ENTRY(GNUTLS_CIPHER_TWOFISH_CBC, 16, 16, CIPHER_BLOCK, 16),
+	GNUTLS_CIPHER_ENTRY(GNUTLS_CIPHER_ARCFOUR, 1, 16, CIPHER_STREAM, 0),
+	GNUTLS_CIPHER_ENTRY(GNUTLS_CIPHER_NULL, 1, 0, CIPHER_STREAM, 0),
 	{0}
 };
 
@@ -130,7 +128,7 @@ typedef struct gnutls_hash_entry gnutls_hash_entry;
 static const gnutls_hash_entry hash_algorithms[] = {
 	GNUTLS_HASH_ENTRY(GNUTLS_MAC_SHA, 20),
 	GNUTLS_HASH_ENTRY(GNUTLS_MAC_MD5, 16),
-	GNUTLS_HASH_ENTRY(GNUTLS_NULL_MAC, 0),
+	GNUTLS_HASH_ENTRY(GNUTLS_MAC_NULL, 0),
 	{0}
 };
 
@@ -154,9 +152,9 @@ struct gnutls_compression_entry {
 
 typedef struct gnutls_compression_entry gnutls_compression_entry;
 static const gnutls_compression_entry compression_algorithms[] = {
-	GNUTLS_COMPRESSION_ENTRY(GNUTLS_NULL_COMPRESSION, 0),
+	GNUTLS_COMPRESSION_ENTRY(GNUTLS_COMP_NULL, 0),
 #ifdef HAVE_LIBZ
-	GNUTLS_COMPRESSION_ENTRY(GNUTLS_ZLIB, 224),
+	GNUTLS_COMPRESSION_ENTRY(GNUTLS_COMP_ZLIB, 224),
 #endif
 	{0}
 };
@@ -187,9 +185,9 @@ extern MOD_AUTH_STRUCT anon_auth_struct;
 extern MOD_AUTH_STRUCT srp_auth_struct;
 
 static const gnutls_kx_algo_entry kx_algorithms[] = {
-	GNUTLS_KX_ALGO_ENTRY(GNUTLS_KX_DH_ANON, &anon_auth_struct),
-	GNUTLS_KX_ALGO_ENTRY(GNUTLS_KX_RSA, &rsa_auth_struct),
-	GNUTLS_KX_ALGO_ENTRY(GNUTLS_KX_DHE_RSA, &dhe_rsa_auth_struct),
+	GNUTLS_KX_ALGO_ENTRY(GNUTLS_KX_ANON_DH, &anon_auth_struct),
+	GNUTLS_KX_ALGO_ENTRY(GNUTLS_KX_X509PKI_RSA, &rsa_auth_struct),
+	GNUTLS_KX_ALGO_ENTRY(GNUTLS_KX_X509PKI_DHE_RSA, &dhe_rsa_auth_struct),
 	GNUTLS_KX_ALGO_ENTRY(GNUTLS_KX_SRP, &srp_auth_struct),
 	{0}
 };
@@ -215,14 +213,14 @@ typedef struct {
 	MACAlgorithm mac_algorithm;
 } gnutls_cipher_suite_entry;
 
-#define GNUTLS_RSA_NULL_MD5 { 0x00, 0x01 }
+#define GNUTLS_X509PKI_RSA_NULL_MD5 { 0x00, 0x01 }
 
-#define GNUTLS_DH_anon_3DES_EDE_CBC_SHA { 0x00, 0x1B }
-#define GNUTLS_DH_anon_ARCFOUR_MD5 { 0x00, 0x18 }
-#define GNUTLS_DH_anon_RIJNDAEL_128_CBC_SHA { 0x00, 0x34 }
-#define GNUTLS_DH_anon_RIJNDAEL_256_CBC_SHA { 0x00, 0x3A }
+#define GNUTLS_ANON_DH_3DES_EDE_CBC_SHA { 0x00, 0x1B }
+#define GNUTLS_ANON_DH_ARCFOUR_MD5 { 0x00, 0x18 }
+#define GNUTLS_ANON_DH_RIJNDAEL_128_CBC_SHA { 0x00, 0x34 }
+#define GNUTLS_ANON_DH_RIJNDAEL_256_CBC_SHA { 0x00, 0x3A }
 /* Twofish is a gnutls extension */
-#define GNUTLS_DH_anon_TWOFISH_128_CBC_SHA { 0xF6, 0x50 }
+#define GNUTLS_ANON_DH_TWOFISH_128_CBC_SHA { 0xF6, 0x50 }
 
 /* SRP is a gnutls extension - for now */
 #define GNUTLS_SRP_3DES_EDE_CBC_SHA { 0x00, 0x5B }
@@ -233,159 +231,116 @@ typedef struct {
 #define GNUTLS_SRP_TWOFISH_128_CBC_SHA { 0xF6, 0x64 }
 
 /* RSA */
-#define GNUTLS_RSA_ARCFOUR_SHA { 0x00, 0x05 }
-#define GNUTLS_RSA_ARCFOUR_MD5 { 0x00, 0x04 }
-#define GNUTLS_RSA_3DES_EDE_CBC_SHA { 0x00, 0x0A }
-#define GNUTLS_RSA_DES_CBC_SHA { 0x00, 0x09 }
-#define GNUTLS_RSA_RIJNDAEL_128_CBC_SHA { 0x00, 0x2F }
-#define GNUTLS_RSA_RIJNDAEL_256_CBC_SHA { 0x00, 0x35 }
-#define GNUTLS_RSA_TWOFISH_128_CBC_SHA { 0xF6, 0x51 }
+#define GNUTLS_X509PKI_RSA_ARCFOUR_SHA { 0x00, 0x05 }
+#define GNUTLS_X509PKI_RSA_ARCFOUR_MD5 { 0x00, 0x04 }
+#define GNUTLS_X509PKI_RSA_3DES_EDE_CBC_SHA { 0x00, 0x0A }
+#define GNUTLS_X509PKI_RSA_DES_CBC_SHA { 0x00, 0x09 }
+#define GNUTLS_X509PKI_RSA_RIJNDAEL_128_CBC_SHA { 0x00, 0x2F }
+#define GNUTLS_X509PKI_RSA_RIJNDAEL_256_CBC_SHA { 0x00, 0x35 }
+#define GNUTLS_X509PKI_RSA_TWOFISH_128_CBC_SHA { 0xF6, 0x51 }
 
-/* DH_DSS */
-#define GNUTLS_DH_DSS_RIJNDAEL_128_CBC_SHA { 0x00, 0x30 }
-#define GNUTLS_DH_DSS_TWOFISH_128_CBC_SHA { 0xF6, 0x52 }
-#define GNUTLS_DH_DSS_DES_CBC_SHA { 0x00, 0x0C }
-#define GNUTLS_DH_DSS_RIJNDAEL_256_CBC_SHA { 0x00, 0x36 }
-#define GNUTLS_DH_DSS_3DES_EDE_CBC_SHA { 0x00, 0x0D }
-
-/* DHE_DSS */
-#define GNUTLS_DHE_DSS_RIJNDAEL_256_CBC_SHA { 0x00, 0x38 }
-#define GNUTLS_DHE_DSS_RIJNDAEL_128_CBC_SHA { 0x00, 0x32 }
-#define GNUTLS_DHE_DSS_DES_CBC_SHA { 0x00, 0x12 }
-#define GNUTLS_DHE_DSS_TWOFISH_128_CBC_SHA { 0xF6, 0x54 }
-#define GNUTLS_DHE_DSS_3DES_EDE_CBC_SHA { 0x00, 0x13 }
-
-/* DHE_RSA */
-#define GNUTLS_DHE_RSA_TWOFISH_128_CBC_SHA { 0xF6, 0x55 }
-#define GNUTLS_DHE_RSA_3DES_EDE_CBC_SHA { 0x00, 0x16 }
-#define GNUTLS_DHE_RSA_DES_CBC_SHA { 0x00, 0x15 }
-#define GNUTLS_DHE_RSA_RIJNDAEL_128_CBC_SHA { 0x00, 0x33 }
-#define GNUTLS_DHE_RSA_RIJNDAEL_256_CBC_SHA { 0x00, 0x39 }
-
-/* DH_RSA */
-#define GNUTLS_DH_RSA_TWOFISH_128_CBC_SHA { 0xF6, 0x53 }
-#define GNUTLS_DH_RSA_DES_CBC_SHA { 0x00, 0x0F }
-#define GNUTLS_DH_RSA_3DES_EDE_CBC_SHA { 0x00, 0x10 }
-#define GNUTLS_DH_RSA_RIJNDAEL_256_CBC_SHA { 0x00, 0x37 }
-#define GNUTLS_DH_RSA_RIJNDAEL_128_CBC_SHA { 0x00, 0x31 }
+/* X509PKI_DHE_DSS */
+#define GNUTLS_X509PKI_DHE_DSS_RIJNDAEL_256_CBC_SHA { 0x00, 0x38 }
+#define GNUTLS_X509PKI_DHE_DSS_RIJNDAEL_128_CBC_SHA { 0x00, 0x32 }
+#define GNUTLS_X509PKI_DHE_DSS_DES_CBC_SHA { 0x00, 0x12 }
+#define GNUTLS_X509PKI_DHE_DSS_TWOFISH_128_CBC_SHA { 0xF6, 0x54 }
+#define GNUTLS_X509PKI_DHE_DSS_3DES_EDE_CBC_SHA { 0x00, 0x13 }
 
+/* X509PKI_DHE_RSA */
+#define GNUTLS_X509PKI_DHE_RSA_TWOFISH_128_CBC_SHA { 0xF6, 0x55 }
+#define GNUTLS_X509PKI_DHE_RSA_3DES_EDE_CBC_SHA { 0x00, 0x16 }
+#define GNUTLS_X509PKI_DHE_RSA_DES_CBC_SHA { 0x00, 0x15 }
+#define GNUTLS_X509PKI_DHE_RSA_RIJNDAEL_128_CBC_SHA { 0x00, 0x33 }
+#define GNUTLS_X509PKI_DHE_RSA_RIJNDAEL_256_CBC_SHA { 0x00, 0x39 }
 
 static const gnutls_cipher_suite_entry cs_algorithms[] = {
-	/* DH_anon */
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DH_anon_ARCFOUR_MD5,
-				  GNUTLS_ARCFOUR,
-				  GNUTLS_KX_DH_ANON, GNUTLS_MAC_MD5),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DH_anon_3DES_EDE_CBC_SHA,
-				  GNUTLS_3DES_CBC, GNUTLS_KX_DH_ANON,
+	/* ANON_DH */
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_ANON_DH_ARCFOUR_MD5,
+				  GNUTLS_CIPHER_ARCFOUR,
+				  GNUTLS_KX_ANON_DH, GNUTLS_MAC_MD5),
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_ANON_DH_3DES_EDE_CBC_SHA,
+				  GNUTLS_CIPHER_3DES_CBC, GNUTLS_KX_ANON_DH,
 				  GNUTLS_MAC_SHA),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DH_anon_RIJNDAEL_128_CBC_SHA,
-				  GNUTLS_RIJNDAEL_CBC, GNUTLS_KX_DH_ANON,
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_ANON_DH_RIJNDAEL_128_CBC_SHA,
+				  GNUTLS_CIPHER_RIJNDAEL_CBC, GNUTLS_KX_ANON_DH,
 				  GNUTLS_MAC_SHA),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DH_anon_RIJNDAEL_256_CBC_SHA,
-				  GNUTLS_RIJNDAEL256_CBC, GNUTLS_KX_DH_ANON,
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_ANON_DH_RIJNDAEL_256_CBC_SHA,
+				  GNUTLS_CIPHER_RIJNDAEL256_CBC, GNUTLS_KX_ANON_DH,
 				  GNUTLS_MAC_SHA),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DH_anon_TWOFISH_128_CBC_SHA,
-				  GNUTLS_TWOFISH_CBC, GNUTLS_KX_DH_ANON,
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_ANON_DH_TWOFISH_128_CBC_SHA,
+				  GNUTLS_CIPHER_TWOFISH_CBC, GNUTLS_KX_ANON_DH,
 				  GNUTLS_MAC_SHA),
 
 	/* SRP */
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_ARCFOUR_SHA,
-				  GNUTLS_ARCFOUR,
+				  GNUTLS_CIPHER_ARCFOUR,
 				  GNUTLS_KX_SRP, GNUTLS_MAC_SHA),
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_ARCFOUR_MD5,
-				  GNUTLS_ARCFOUR,
+				  GNUTLS_CIPHER_ARCFOUR,
 				  GNUTLS_KX_SRP, GNUTLS_MAC_MD5),
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_3DES_EDE_CBC_SHA,
-				  GNUTLS_3DES_CBC, GNUTLS_KX_SRP,
+				  GNUTLS_CIPHER_3DES_CBC, GNUTLS_KX_SRP,
 				  GNUTLS_MAC_SHA),
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_RIJNDAEL_128_CBC_SHA,
-				  GNUTLS_RIJNDAEL_CBC, GNUTLS_KX_SRP,
+				  GNUTLS_CIPHER_RIJNDAEL_CBC, GNUTLS_KX_SRP,
 				  GNUTLS_MAC_SHA),
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_RIJNDAEL_256_CBC_SHA,
-				  GNUTLS_RIJNDAEL256_CBC, GNUTLS_KX_SRP,
+				  GNUTLS_CIPHER_RIJNDAEL256_CBC, GNUTLS_KX_SRP,
 				  GNUTLS_MAC_SHA),
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_TWOFISH_128_CBC_SHA,
-				  GNUTLS_TWOFISH_CBC, GNUTLS_KX_SRP,
+				  GNUTLS_CIPHER_TWOFISH_CBC, GNUTLS_KX_SRP,
 				  GNUTLS_MAC_SHA),
 
-	/* DH_DSS */
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DH_DSS_3DES_EDE_CBC_SHA,
-				  GNUTLS_3DES_CBC,
-				  GNUTLS_KX_DH_DSS, GNUTLS_MAC_SHA),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DH_DSS_RIJNDAEL_128_CBC_SHA,
-				  GNUTLS_RIJNDAEL_CBC, GNUTLS_KX_DH_DSS,
+	/* X509PKI_DHE_DSS */
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_X509PKI_DHE_DSS_TWOFISH_128_CBC_SHA,
+				  GNUTLS_CIPHER_TWOFISH_CBC, GNUTLS_KX_X509PKI_DHE_DSS,
 				  GNUTLS_MAC_SHA),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DH_DSS_RIJNDAEL_256_CBC_SHA,
-				  GNUTLS_RIJNDAEL256_CBC, GNUTLS_KX_DH_DSS,
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_X509PKI_DHE_DSS_3DES_EDE_CBC_SHA,
+				  GNUTLS_CIPHER_3DES_CBC, GNUTLS_KX_X509PKI_DHE_DSS,
 				  GNUTLS_MAC_SHA),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DH_DSS_TWOFISH_128_CBC_SHA,
-				  GNUTLS_TWOFISH_CBC, GNUTLS_KX_DH_DSS,
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_X509PKI_DHE_DSS_RIJNDAEL_128_CBC_SHA,
+				  GNUTLS_CIPHER_RIJNDAEL_CBC, GNUTLS_KX_X509PKI_DHE_DSS,
+				  GNUTLS_MAC_SHA),
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_X509PKI_DHE_DSS_RIJNDAEL_256_CBC_SHA,
+				  GNUTLS_CIPHER_RIJNDAEL256_CBC, GNUTLS_KX_X509PKI_DHE_DSS,
 				  GNUTLS_MAC_SHA),
 
-	/* DH_RSA */ 
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DH_RSA_3DES_EDE_CBC_SHA,
-				  GNUTLS_3DES_CBC,
-				  GNUTLS_KX_DH_RSA, GNUTLS_MAC_SHA),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DH_RSA_RIJNDAEL_128_CBC_SHA,
-				  GNUTLS_RIJNDAEL_CBC, GNUTLS_KX_DH_RSA,
+	/* X509PKI_DHE_RSA */
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_X509PKI_DHE_RSA_TWOFISH_128_CBC_SHA,
+				  GNUTLS_CIPHER_TWOFISH_CBC, GNUTLS_KX_X509PKI_DHE_RSA,
 				  GNUTLS_MAC_SHA),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DH_RSA_RIJNDAEL_256_CBC_SHA,
-				  GNUTLS_RIJNDAEL256_CBC, GNUTLS_KX_DH_RSA,
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_X509PKI_DHE_RSA_3DES_EDE_CBC_SHA,
+				  GNUTLS_CIPHER_3DES_CBC, GNUTLS_KX_X509PKI_DHE_RSA,
 				  GNUTLS_MAC_SHA),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DH_RSA_TWOFISH_128_CBC_SHA,
-				  GNUTLS_TWOFISH_CBC, GNUTLS_KX_DH_RSA,
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_X509PKI_DHE_RSA_RIJNDAEL_128_CBC_SHA,
+				  GNUTLS_CIPHER_RIJNDAEL_CBC, GNUTLS_KX_X509PKI_DHE_RSA,
+				  GNUTLS_MAC_SHA),
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_X509PKI_DHE_RSA_RIJNDAEL_256_CBC_SHA,
+				  GNUTLS_CIPHER_RIJNDAEL256_CBC, GNUTLS_KX_X509PKI_DHE_RSA,
 				  GNUTLS_MAC_SHA),
 
-	/* DHE_DSS */
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_DSS_TWOFISH_128_CBC_SHA,
-				  GNUTLS_TWOFISH_CBC, GNUTLS_KX_DHE_DSS,
-				  GNUTLS_MAC_SHA),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_DSS_3DES_EDE_CBC_SHA,
-				  GNUTLS_3DES_CBC, GNUTLS_KX_DHE_DSS,
-				  GNUTLS_MAC_SHA),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_DSS_RIJNDAEL_128_CBC_SHA,
-				  GNUTLS_RIJNDAEL_CBC, GNUTLS_KX_DHE_DSS,
-				  GNUTLS_MAC_SHA),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_DSS_RIJNDAEL_256_CBC_SHA,
-				  GNUTLS_RIJNDAEL256_CBC, GNUTLS_KX_DHE_DSS,
-				  GNUTLS_MAC_SHA),
+	/* X509PKI_RSA */
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_X509PKI_RSA_NULL_MD5,
+				  GNUTLS_CIPHER_NULL,
+				  GNUTLS_KX_X509PKI_RSA, GNUTLS_MAC_MD5),
 
-	/* DHE_RSA */
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_RSA_TWOFISH_128_CBC_SHA,
-				  GNUTLS_TWOFISH_CBC, GNUTLS_KX_DHE_RSA,
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_X509PKI_RSA_ARCFOUR_SHA,
+				  GNUTLS_CIPHER_ARCFOUR,
+				  GNUTLS_KX_X509PKI_RSA, GNUTLS_MAC_SHA),
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_X509PKI_RSA_ARCFOUR_MD5,
+				  GNUTLS_CIPHER_ARCFOUR,
+				  GNUTLS_KX_X509PKI_RSA, GNUTLS_MAC_MD5),
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_X509PKI_RSA_3DES_EDE_CBC_SHA,
+				  GNUTLS_CIPHER_3DES_CBC,
+				  GNUTLS_KX_X509PKI_RSA, GNUTLS_MAC_SHA),
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_X509PKI_RSA_RIJNDAEL_128_CBC_SHA,
+				  GNUTLS_CIPHER_RIJNDAEL_CBC, GNUTLS_KX_X509PKI_RSA,
 				  GNUTLS_MAC_SHA),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_RSA_3DES_EDE_CBC_SHA,
-				  GNUTLS_3DES_CBC, GNUTLS_KX_DHE_RSA,
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_X509PKI_RSA_RIJNDAEL_256_CBC_SHA,
+				  GNUTLS_CIPHER_RIJNDAEL256_CBC, GNUTLS_KX_X509PKI_RSA,
 				  GNUTLS_MAC_SHA),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_RSA_RIJNDAEL_128_CBC_SHA,
-				  GNUTLS_RIJNDAEL_CBC, GNUTLS_KX_DHE_RSA,
-				  GNUTLS_MAC_SHA),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_RSA_RIJNDAEL_256_CBC_SHA,
-				  GNUTLS_RIJNDAEL256_CBC, GNUTLS_KX_DHE_RSA,
-				  GNUTLS_MAC_SHA),
-
-	/* RSA */
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_NULL_MD5,
-				  GNUTLS_NULL_CIPHER,
-				  GNUTLS_KX_RSA, GNUTLS_MAC_MD5),
-
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_ARCFOUR_SHA,
-				  GNUTLS_ARCFOUR,
-				  GNUTLS_KX_RSA, GNUTLS_MAC_SHA),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_ARCFOUR_MD5,
-				  GNUTLS_ARCFOUR,
-				  GNUTLS_KX_RSA, GNUTLS_MAC_MD5),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_3DES_EDE_CBC_SHA,
-				  GNUTLS_3DES_CBC,
-				  GNUTLS_KX_RSA, GNUTLS_MAC_SHA),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_RIJNDAEL_128_CBC_SHA,
-				  GNUTLS_RIJNDAEL_CBC, GNUTLS_KX_RSA,
-				  GNUTLS_MAC_SHA),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_RIJNDAEL_256_CBC_SHA,
-				  GNUTLS_RIJNDAEL256_CBC, GNUTLS_KX_RSA,
-				  GNUTLS_MAC_SHA),
-	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_RSA_TWOFISH_128_CBC_SHA,
-				  GNUTLS_TWOFISH_CBC, GNUTLS_KX_RSA,
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_X509PKI_RSA_TWOFISH_128_CBC_SHA,
+				  GNUTLS_CIPHER_TWOFISH_CBC, GNUTLS_KX_X509PKI_RSA,
 				  GNUTLS_MAC_SHA),
 
 	{0}
@@ -438,7 +393,7 @@ const char *gnutls_mac_get_name(MACAlgorithm algorithm)
 
 	/* avoid prefix */
 	GNUTLS_HASH_ALG_LOOP(ret =
-			     p->name + sizeof("GNUTLS_") - 1);
+			     p->name + sizeof("GNUTLS_MAC_") - 1);
 
 	return ret;
 }
@@ -495,7 +450,7 @@ const char *gnutls_compression_get_name(CompressionMethod algorithm)
 
 	/* avoid prefix */
 	GNUTLS_COMPRESSION_ALG_LOOP(ret =
-				    p->name + sizeof("GNUTLS_") -
+				    p->name + sizeof("GNUTLS_COMP_") -
 					   1);
 
 	return ret;
@@ -613,7 +568,7 @@ const char *gnutls_cipher_get_name(BulkCipherAlgorithm algorithm)
 	char *ret = NULL;
 
 	/* avoid prefix */
-	GNUTLS_ALG_LOOP(ret = p->name + sizeof("GNUTLS_") - 1);
+	GNUTLS_ALG_LOOP(ret = p->name + sizeof("GNUTLS_CIPHER_") - 1);
 
 	return ret;
 }
@@ -675,7 +630,7 @@ const char *gnutls_kx_get_name(KXAlgorithm algorithm)
 	char *ret = NULL;
 
 	/* avoid prefix */
-	GNUTLS_KX_ALG_LOOP(ret = p->name + sizeof("KX_") - 1);
+	GNUTLS_KX_ALG_LOOP(ret = p->name + sizeof("GNUTLS_KX_") - 1);
 
 	return ret;
 }
@@ -761,13 +716,13 @@ GNUTLS_Version _gnutls_version_max(GNUTLS_STATE state)
 
 
 /**
-  * gnutls_version_get_name - Returns a string with the name of the specified SSL/TLS version
+  * gnutls_protocol_get_name - Returns a string with the name of the specified SSL/TLS version
   * @version: is a (gnutls) version number
   *
   * Returns a string that contains the name 
   * of the specified TLS version.
   **/
-const char *gnutls_version_get_name(GNUTLS_Version version)
+const char *gnutls_protocol_get_name(GNUTLS_Version version)
 {
 	char *ret = NULL;
 
