@@ -18,11 +18,11 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
-int gnutls_set_cache_expiration( GNUTLS_STATE state, int seconds);
-int gnutls_set_db_name( GNUTLS_STATE state, char* filename);
+void gnutls_set_cache_expiration( GNUTLS_STATE state, int seconds);
+int gnutls_db_set_name( GNUTLS_STATE state, char* filename);
 int _gnutls_server_register_current_session( GNUTLS_STATE state);
 int _gnutls_server_restore_session( GNUTLS_STATE state, uint8* session_id, int session_id_size);
-int gnutls_clean_db( GNUTLS_STATE state);
+int gnutls_db_clean( GNUTLS_STATE state);
 int _gnutls_db_remove_session( GNUTLS_STATE state, uint8* session_id, int session_id_size);
 int _gnutls_store_session( GNUTLS_STATE state, gnutls_datum session_id, gnutls_datum session_data);
 gnutls_datum _gnutls_retrieve_session( GNUTLS_STATE state, gnutls_datum session_id);
