@@ -54,7 +54,7 @@ void _gnutls_set_current_version(GNUTLS_STATE state, GNUTLS_Version version) {
 }
 
 /**
-  * gnutls_set_lowat - Used to set the lowat value in order for select to check for pending data.
+  * gnutls_transport_set_lowat - Used to set the lowat value in order for select to check for pending data.
   * @state: is a &GNUTLS_STATE structure.
   * @num: is the low water value.
   *
@@ -66,7 +66,7 @@ void _gnutls_set_current_version(GNUTLS_STATE state, GNUTLS_Version version) {
   * Otherwise it must be called and set lowat to zero.
   *
   **/
-void gnutls_set_lowat(GNUTLS_STATE state, int num) {
+void gnutls_transport_set_lowat(GNUTLS_STATE state, int num) {
 	state->gnutls_internals.lowat = num;
 }
 
@@ -141,9 +141,9 @@ int default_protocol_list[] = { GNUTLS_TLS1, 0 };
 
 	(*state)->gnutls_internals.expire_time = DEFAULT_EXPIRE_TIME; /* one hour default */
 
-	gnutls_set_lowat((*state), DEFAULT_LOWAT); /* the default for tcp */
+	gnutls_transport_set_lowat((*state), DEFAULT_LOWAT); /* the default for tcp */
 
-	gnutls_set_max_handshake_data_buffer_size( (*state), MAX_HANDSHAKE_DATA_BUFFER_SIZE);
+	gnutls_handshake_set_max_data_buffer_size( (*state), MAX_HANDSHAKE_DATA_BUFFER_SIZE);
 
 	/* Allocate a minimum size for recv_data 
 	 * This is allocated in order to avoid small messages, makeing
@@ -387,7 +387,7 @@ int gnutls_PRF( opaque * secret, int secret_size, uint8 * label, int label_size,
 }
 
 /**
-  * gnutls_send_alert - This function sends an alert message to the peer
+  * gnutls_alert_send - This function sends an alert message to the peer
   * @state: is a &GNUTLS_STATE structure.
   * @level: is the level of the alert
   * @desc: is the alert description
@@ -399,7 +399,7 @@ int gnutls_PRF( opaque * secret, int secret_size, uint8 * label, int label_size,
   * Returns 0 on success.
   *
   **/
-int gnutls_send_alert( GNUTLS_STATE state, AlertLevel level, AlertDescription desc)
+int gnutls_alert_send( GNUTLS_STATE state, AlertLevel level, AlertDescription desc)
 {
 	uint8 data[2];
 	int ret;
@@ -421,7 +421,7 @@ int gnutls_send_alert( GNUTLS_STATE state, AlertLevel level, AlertDescription de
  * on the error message.
  */
 /**
-  * gnutls_send_appropriate_alert - This function sends an alert to the peer depending on the error code
+  * gnutls_alert_send_appropriate - This function sends an alert to the peer depending on the error code
   * @state: is a &GNUTLS_STATE structure.
   * @err: is an integer
   *
@@ -437,39 +437,39 @@ int gnutls_send_alert( GNUTLS_STATE state, AlertLevel level, AlertDescription de
   * been sent to the peer.
   *
   **/
-int gnutls_send_appropriate_alert( GNUTLS_STATE state, int err) {
+int gnutls_alert_send_appropriate( GNUTLS_STATE state, int err) {
 int ret = GNUTLS_E_UNIMPLEMENTED_FEATURE;
 	switch (err) { /* send appropriate alert */
 		case GNUTLS_E_MAC_FAILED:
-			ret = gnutls_send_alert( state, GNUTLS_AL_FATAL, GNUTLS_A_BAD_RECORD_MAC);
+			ret = gnutls_alert_send( state, GNUTLS_AL_FATAL, GNUTLS_A_BAD_RECORD_MAC);
 			break;
 		case GNUTLS_E_DECRYPTION_FAILED:
-			ret = gnutls_send_alert( state, GNUTLS_AL_FATAL, GNUTLS_A_DECRYPTION_FAILED);
+			ret = gnutls_alert_send( state, GNUTLS_AL_FATAL, GNUTLS_A_DECRYPTION_FAILED);
 			break;
 		case GNUTLS_E_DECOMPRESSION_FAILED:
-			ret = gnutls_send_alert( state, GNUTLS_AL_FATAL, GNUTLS_A_DECOMPRESSION_FAILURE);
+			ret = gnutls_alert_send( state, GNUTLS_AL_FATAL, GNUTLS_A_DECOMPRESSION_FAILURE);
 			break;
 		case GNUTLS_E_ILLEGAL_PARAMETER:
-                        ret = gnutls_send_alert( state, GNUTLS_AL_FATAL, GNUTLS_A_ILLEGAL_PARAMETER);
+                        ret = gnutls_alert_send( state, GNUTLS_AL_FATAL, GNUTLS_A_ILLEGAL_PARAMETER);
                         break;
 		case GNUTLS_E_ASN1_PARSING_ERROR:
 		case GNUTLS_E_NO_CERTIFICATE_FOUND:
-                        ret = gnutls_send_alert( state, GNUTLS_AL_FATAL, GNUTLS_A_BAD_CERTIFICATE);
+                        ret = gnutls_alert_send( state, GNUTLS_AL_FATAL, GNUTLS_A_BAD_CERTIFICATE);
                         break;
 		case GNUTLS_E_UNKNOWN_CIPHER_SUITE:
-                        ret = gnutls_send_alert( state, GNUTLS_AL_FATAL, GNUTLS_A_HANDSHAKE_FAILURE);
+                        ret = gnutls_alert_send( state, GNUTLS_AL_FATAL, GNUTLS_A_HANDSHAKE_FAILURE);
                         break;
 		case GNUTLS_E_UNEXPECTED_PACKET:
-                        ret = gnutls_send_alert( state, GNUTLS_AL_FATAL, GNUTLS_A_UNEXPECTED_MESSAGE);
+                        ret = gnutls_alert_send( state, GNUTLS_AL_FATAL, GNUTLS_A_UNEXPECTED_MESSAGE);
                         break;
 		case GNUTLS_E_REHANDSHAKE:
-                        ret = gnutls_send_alert( state, GNUTLS_AL_WARNING, GNUTLS_A_NO_RENEGOTIATION);
+                        ret = gnutls_alert_send( state, GNUTLS_AL_WARNING, GNUTLS_A_NO_RENEGOTIATION);
                         break;
 		case GNUTLS_E_UNSUPPORTED_VERSION_PACKET:
-                        ret = gnutls_send_alert( state, GNUTLS_AL_WARNING, GNUTLS_A_PROTOCOL_VERSION);
+                        ret = gnutls_alert_send( state, GNUTLS_AL_WARNING, GNUTLS_A_PROTOCOL_VERSION);
 			break;
 		case GNUTLS_E_UNEXPECTED_PACKET_LENGTH:
-			ret = gnutls_send_alert( state, GNUTLS_AL_FATAL, GNUTLS_A_RECORD_OVERFLOW);
+			ret = gnutls_alert_send( state, GNUTLS_AL_FATAL, GNUTLS_A_RECORD_OVERFLOW);
 			break;
 	}
 	return ret;
@@ -508,7 +508,7 @@ int gnutls_bye( GNUTLS_STATE state, CloseRequest how)
 			if (STATE==STATE60) {
 				ret = _gnutls_write_flush( state);
 			} else {
-				ret = gnutls_send_alert( state, GNUTLS_AL_WARNING, GNUTLS_A_CLOSE_NOTIFY);
+				ret = gnutls_alert_send( state, GNUTLS_AL_WARNING, GNUTLS_A_CLOSE_NOTIFY);
 				STATE = STATE60;
 			}
 
@@ -559,7 +559,6 @@ ssize_t gnutls_send_int( GNUTLS_STATE state, ContentType type, HandshakeType hty
 	}
 
 	if (state->gnutls_internals.valid_connection == VALID_FALSE || state->gnutls_internals.may_write != 0) {
-		gnutls_assert();
 		return GNUTLS_E_INVALID_SESSION;
 	}
 
@@ -716,7 +715,6 @@ ssize_t gnutls_recv_int( GNUTLS_STATE state, ContentType type, HandshakeType hty
 	ret = 0;
 
 	if (sizeofdata == 0 || data == NULL) {
-		gnutls_assert();
 		return GNUTLS_E_INVALID_PARAMETERS;
 	}
 
@@ -1123,7 +1121,7 @@ gnutls_check_version( const char *req_version )
 }
 
 /**
-  * gnutls_get_last_alert - Returns the last alert number received.
+  * gnutls_alert_get_last - Returns the last alert number received.
   * @state: is a &GNUTLS_STATE structure.
   *
   * Returns the last alert number received. This function
@@ -1132,7 +1130,7 @@ gnutls_check_version( const char *req_version )
   * The peer may send alerts if he thinks some things were not 
   * right. Check gnutls.h for the available alert descriptions.
   **/
-AlertDescription gnutls_get_last_alert( GNUTLS_STATE state) {
+AlertDescription gnutls_alert_get_last( GNUTLS_STATE state) {
 	return state->gnutls_internals.last_alert;
 }
 
@@ -1180,7 +1178,7 @@ ssize_t gnutls_read( GNUTLS_STATE state, void *data, size_t sizeofdata) {
 }
 
 /**
-  * gnutls_get_max_record_size - returns the maximum record size
+  * gnutls_record_get_max_size - returns the maximum record size
   * @state: is a &GNUTLS_STATE structure.
   *
   * This function returns the maximum record size in this connection.
@@ -1188,13 +1186,13 @@ ssize_t gnutls_read( GNUTLS_STATE state, void *data, size_t sizeofdata) {
   * first handshake message.
   *
   **/
-size_t gnutls_get_max_record_size( GNUTLS_STATE state) {
+size_t gnutls_record_get_max_size( GNUTLS_STATE state) {
 	return state->security_parameters.max_record_size;
 }
 
 
 /**
-  * gnutls_set_max_record_size - sets the maximum record size
+  * gnutls_record_set_max_size - sets the maximum record size
   * @state: is a &GNUTLS_STATE structure.
   * @size: is the new size
   *
@@ -1211,7 +1209,7 @@ size_t gnutls_get_max_record_size( GNUTLS_STATE state) {
   * Not all TLS implementations use or even understand this extension.
   *
   **/
-size_t gnutls_set_max_record_size( GNUTLS_STATE state, size_t size) {
+size_t gnutls_record_set_max_size( GNUTLS_STATE state, size_t size) {
 size_t new_size;
 
 	if (state->security_parameters.entity==GNUTLS_SERVER)
