@@ -20,24 +20,28 @@
 #include "gnutls_int.h"
 #include "gnutls_errors.h"
 #include "debug.h"
+#include <gnutls_session_pack.h>
 
-#define SESSION_SIZE sizeof(SecurityParameters) + sizeof(state->gnutls_key->auth_info_size) + state->gnutls_key->auth_info_size
+#define SESSION_SIZE _gnutls_session_size( state)
 
 /**
-  * gnutls_get_current_session - Returns all session parameters.
+  * gnutls_session_get_data - Returns all session parameters.
   * @state: is a &GNUTLS_STATE structure.
   * @session: is a pointer to space to hold the session.
   * @session_size: is the session's size, or it will be set by the function.
   *
   * Returns all session parameters - in order to support resuming.
   * The client should call this - and keep the returned session - if he wants to
-  * resume that current version later by calling gnutls_set_current_session()
+  * resume that current version later by calling gnutls_session_set_data()
   * This function must be called after a successful handshake.
   *
   * Resuming sessions is really useful and speedups connections after a succesful one.
   **/
-int gnutls_get_current_session( GNUTLS_STATE state, opaque* session, int *session_size) {
+int gnutls_session_get_data( GNUTLS_STATE state, opaque* session, int *session_size) {
 
+	gnutls_datum psession;
+	int ret;
+	
 	if (*session_size < SESSION_SIZE || session==NULL) {
 		*session_size = SESSION_SIZE;
 		session = NULL; /* return with the new session_size value */
@@ -48,17 +52,22 @@ int gnutls_get_current_session( GNUTLS_STATE state, opaque* session, int *sessio
 	if (session==NULL) {
 		return 0;
 	}
-	memcpy( session, &state->security_parameters, sizeof(SecurityParameters));
-	memcpy( &session[sizeof(SecurityParameters)], &state->gnutls_key->auth_info_size,  sizeof(state->gnutls_key->auth_info_size));
-	memcpy( &session[sizeof(state->gnutls_key->auth_info_size)+sizeof(SecurityParameters)], 
-		state->gnutls_key->auth_info,  state->gnutls_key->auth_info_size);
+	
+	psession.data = session;
+	
+	ret = _gnutls_session_pack( state, &psession);
+	if (ret< 0) {
+		gnutls_assert();
+		return ret;
+	}
+	*session_size = psession.size;
 
 	return 0;
 }
 
 
 /**
-  * gnutls_get_current_session_id - Returns session id.
+  * gnutls_session_get_id - Returns session id.
   * @state: is a &GNUTLS_STATE structure.
   * @session: is a pointer to space to hold the session id.
   * @session_size: is the session id's size, or it will be set by the function.
@@ -70,7 +79,7 @@ int gnutls_get_current_session( GNUTLS_STATE state, opaque* session, int *sessio
   * Session id is some data set by the server, that identify the current session. 
   * In TLS 1.0 session id should not be more than 32 bytes.
   **/
-int gnutls_get_current_session_id( GNUTLS_STATE state, void* session, int *session_size) {
+int gnutls_session_get_id( GNUTLS_STATE state, void* session, int *session_size) {
 
 	*session_size = state->security_parameters.session_id_size;
 	
@@ -84,56 +93,28 @@ int gnutls_get_current_session_id( GNUTLS_STATE state, void* session, int *sessi
 }
 
 /**
-  * gnutls_set_current_session - Sets all session parameters
+  * gnutls_session_set_data - Sets all session parameters
   * @state: is a &GNUTLS_STATE structure.
   * @session: is a pointer to space to hold the session.
   * @session_size: is the session's size
   *
   * Sets all session parameters - in order to support resuming
-  * session must be the one returned by gnutls_get_current_session();
+  * session must be the one returned by gnutls_session_get_data();
   * This function should be called before gnutls_handshake().
   * Keep in mind that session resuming is advisory. The server may
   * choose not to resume the session, thus a full handshake will be
   * performed.
   **/
-int gnutls_set_current_session( GNUTLS_STATE state, opaque* session, int session_size) {
-	int auth_info_size;
-	int timestamp = time(0);
-	SecurityParameters sp;
+int gnutls_session_set_data( GNUTLS_STATE state, opaque* session, int session_size) {
+	int ret;
+	gnutls_datum psession = { session, session_size };
 
-	if ( (session_size - sizeof(SecurityParameters)) 
-		>= sizeof(state->gnutls_key->auth_info_size)) { /* have more data */
-		auth_info_size = *((int*)&session[sizeof(SecurityParameters)]);	
-	} else {
-		auth_info_size = 0;
+	
+	ret = _gnutls_session_unpack( state, &psession);
+	if (ret < 0) {
 		gnutls_assert();
-		return GNUTLS_E_DB_ERROR;
+		return ret;
 	}
 	
-	if (session_size < sizeof(SecurityParameters)) {
-		gnutls_assert();
-		return GNUTLS_E_UNIMPLEMENTED_FEATURE;
-	}
-	
-	memcpy( &sp, session, sizeof(SecurityParameters));
-	if ( timestamp - sp.timestamp <= state->gnutls_internals.expire_time 
-		&& sp.timestamp <= timestamp) {
-
-		memcpy( &state->gnutls_internals.resumed_security_parameters, &sp, sizeof(SecurityParameters));
-		if (auth_info_size > 0) {
-			state->gnutls_key->auth_info = gnutls_malloc(auth_info_size);
-			if (state->gnutls_key->auth_info==NULL) {
-				gnutls_assert();
-				return GNUTLS_E_MEMORY_ERROR;
-			}
-			state->gnutls_key->auth_info_size = auth_info_size;
-			memcpy( state->gnutls_key->auth_info, &session[sizeof(SecurityParameters)+sizeof(state->gnutls_key->auth_info_size)], auth_info_size);
-		} else { /* set to null */
-			state->gnutls_key->auth_info_size = 0;
-			state->gnutls_key->auth_info = NULL;
-		}
-	} else {
-		return GNUTLS_E_EXPIRED;
-	}
 	return 0;
 }
