@@ -64,12 +64,12 @@ int cert_list_size = 0;
 	tmp = gnutls_kx_get_name(gnutls_kx_get_algo( state));
 	printf("- Key Exchange: %s\n", tmp);
 
-	cred = gnutls_get_auth_type(state);
+	cred = gnutls_auth_get_type(state);
 	switch(cred) {
 		case GNUTLS_ANON:
 			printf("- Anonymous DH using prime of %d bits\n",
 			       gnutls_anon_client_get_dh_bits( state));
-
+			break;
 		case GNUTLS_X509PKI:
 			cert_list = gnutls_x509pki_client_get_peer_certificate_list( state, &cert_list_size);
 			status = gnutls_x509pki_client_get_peer_certificate_status( state);
@@ -201,8 +201,8 @@ int main(int argc, char** argv)
 		fprintf(stderr, "memory error\n");
 		exit(1);
 	}
-	gnutls_x509pki_set_client_trust( xcred, CAFILE, CRLFILE);
-	gnutls_x509pki_set_client_key( xcred, CLICERTFILE, CLIKEYFILE);
+	gnutls_x509pki_set_client_trust_file( xcred, CAFILE, CRLFILE);
+	gnutls_x509pki_set_client_key_file( xcred, CLICERTFILE, CLIKEYFILE);
 	gnutls_x509pki_set_client_cert_callback( xcred, cert_callback);
 
 	/* SRP stuff */
@@ -242,9 +242,9 @@ int main(int argc, char** argv)
 	gnutls_protocol_set_priority( state, protocol_priority);
 	gnutls_mac_set_priority(state, mac_priority);
 
-	gnutls_set_cred( state, GNUTLS_ANON, anon_cred);
-	gnutls_set_cred( state, GNUTLS_SRP, cred);
-	gnutls_set_cred( state, GNUTLS_X509PKI, xcred);
+	gnutls_cred_set( state, GNUTLS_ANON, anon_cred);
+	gnutls_cred_set( state, GNUTLS_SRP, cred);
+	gnutls_cred_set( state, GNUTLS_X509PKI, xcred);
 
 /* This TLS extension may break old implementations.
  */
@@ -255,7 +255,7 @@ int main(int argc, char** argv)
 
 	if (ret < 0) {
 		if (ret==GNUTLS_E_WARNING_ALERT_RECEIVED || ret==GNUTLS_E_FATAL_ALERT_RECEIVED)
-			printf("*** Received alert [%d]\n", gnutls_get_last_alert(state));
+			printf("*** Received alert [%d]\n", gnutls_alert_get_last(state));
 
 		fprintf(stderr, "*** Handshake has failed\n");
 		gnutls_perror(ret);
@@ -303,9 +303,9 @@ int main(int argc, char** argv)
 	gnutls_protocol_set_priority( state, protocol_priority);
 	gnutls_mac_set_priority(state, mac_priority);
 
-	gnutls_set_cred( state, GNUTLS_ANON, NULL);
-	gnutls_set_cred( state, GNUTLS_SRP, cred);
-	gnutls_set_cred( state, GNUTLS_X509PKI, xcred);
+	gnutls_cred_set( state, GNUTLS_ANON, NULL);
+	gnutls_cred_set( state, GNUTLS_SRP, cred);
+	gnutls_cred_set( state, GNUTLS_X509PKI, xcred);
 
 #ifdef RESUME
 	gnutls_session_set_data( state, session, session_size);
@@ -319,7 +319,7 @@ int main(int argc, char** argv)
 
 	if (ret < 0) {
 		if (ret==GNUTLS_E_WARNING_ALERT_RECEIVED || ret==GNUTLS_E_FATAL_ALERT_RECEIVED)
-			printf("*** Received alert [%d]\n", gnutls_get_last_alert(state));
+			printf("*** Received alert [%d]\n", gnutls_alert_get_last(state));
 		fprintf(stderr, "*** Handshake failed\n");
 		gnutls_perror(ret);
 		gnutls_deinit(state);
@@ -374,7 +374,7 @@ int main(int argc, char** argv)
 				}
 			} else {
 				if (ret==GNUTLS_E_WARNING_ALERT_RECEIVED || ret==GNUTLS_E_FATAL_ALERT_RECEIVED)
-					printf("* Received alert [%d]\n", gnutls_get_last_alert(state));
+					printf("* Received alert [%d]\n", gnutls_alert_get_last(state));
 				if (ret==GNUTLS_E_REHANDSHAKE) {
 					do {
 						ret = gnutls_handshake( state);
