@@ -94,9 +94,9 @@ GNUTLS_STATE initialize_state()
 	gnutls_protocol_set_priority( state, protocol_priority);
 	gnutls_mac_set_priority(state, mac_priority);
 	
-	gnutls_set_cred(state, GNUTLS_ANON, dh_cred);
-	gnutls_set_cred(state, GNUTLS_SRP, srp_cred);
-	gnutls_set_cred(state, GNUTLS_X509PKI, x509_cred);
+	gnutls_cred_set(state, GNUTLS_ANON, dh_cred);
+	gnutls_cred_set(state, GNUTLS_SRP, srp_cred);
+	gnutls_cred_set(state, GNUTLS_X509PKI, x509_cred);
 
 	gnutls_mac_set_priority(state, mac_priority);
 
@@ -127,7 +127,7 @@ void print_info(GNUTLS_STATE state)
 	/* we could also use the KX algorithm to distinguish the functions
 	 * to call, but this is easier.
 	 */
-	cred = gnutls_get_auth_type(state);
+	cred = gnutls_auth_get_type(state);
 
 	switch(cred) {
 		case GNUTLS_SRP:
@@ -308,7 +308,7 @@ int read_request( GNUTLS_STATE state, char *data, int data_size, int rnl)
 
 void check_alert( GNUTLS_STATE state, int ret) {
 	if (ret == GNUTLS_E_WARNING_ALERT_RECEIVED || ret == GNUTLS_E_FATAL_ALERT_RECEIVED) {
-		ret = gnutls_get_last_alert(state);
+		ret = gnutls_alert_get_last(state);
 		if (ret == GNUTLS_A_NO_RENEGOTIATION)
 			printf("* Received NO_RENEGOTIATION alert. Client Does not support renegotiation.\n");
 		else
@@ -354,12 +354,12 @@ int main(int argc, char **argv)
 		exit(1);
 	}
 
-	if (gnutls_x509pki_set_server_trust( x509_cred, CAFILE, CRLFILE) < 0) {
+	if (gnutls_x509pki_set_server_trust_file( x509_cred, CAFILE, CRLFILE) < 0) {
 		fprintf(stderr, "X509 PARSE ERROR\nDid you have ca.pem?\n");
 		exit(1);
 	}
 
-	if (gnutls_x509pki_set_server_key( x509_cred, CERTFILE, KEYFILE) < 0) {
+	if (gnutls_x509pki_set_server_key_file( x509_cred, CERTFILE, KEYFILE) < 0) {
 		fprintf(stderr, "X509 PARSE ERROR\nDid you have key.pem and cert.pem?\n");
 		exit(1);
 	}
@@ -368,7 +368,7 @@ int main(int argc, char **argv)
 	 * Read README.crypt prior to using SRP.
 	 */
 	gnutls_srp_allocate_server_sc( &srp_cred);
-	gnutls_srp_set_server_cred( srp_cred, SRP_PASSWD, SRP_PASSWD_CONF);
+	gnutls_srp_set_server_cred_file( srp_cred, SRP_PASSWD, SRP_PASSWD_CONF);
 
 	gnutls_anon_allocate_server_sc( &dh_cred);
 	gnutls_anon_set_server_cred( dh_cred, 1024);
@@ -466,7 +466,7 @@ int main(int argc, char **argv)
 					ret = gnutls_rehandshake( state);
 				} while( ret==GNUTLS_E_INTERRUPTED || ret==GNUTLS_E_AGAIN);
 
-				if (gnutls_get_last_alert(state)!=GNUTLS_A_NO_RENEGOTIATION) {
+				if (gnutls_alert_get_last(state)!=GNUTLS_A_NO_RENEGOTIATION) {
 					printf("* Requesting rehandshake.\n");
 					/* continue handshake proccess */
 					do {
